@@ -1921,8 +1921,10 @@ if (!strncmp(name, "GL_", 3)) {
 	i(GL_FRAMEZOOM_SGIX)
 	i(GL_FRAMEZOOM_FACTOR_SGIX)
 	i(GL_MAX_FRAMEZOOM_FACTOR_SGIX)
+#if defined(GL_FfdMaskSGIX)
 	i(GL_TEXTURE_DEFORMATION_BIT_SGIX)
 	i(GL_GEOMETRY_DEFORMATION_BIT_SGIX)
+#endif
 	i(GL_GEOMETRY_DEFORMATION_SGIX)
 	i(GL_TEXTURE_DEFORMATION_SGIX)
 	i(GL_DEFORMATIONS_MASK_SGIX)
@@ -2068,6 +2070,7 @@ if (!strncmp(name, "GL_", 3)) {
 	i(GL_TEXTURE_MATERIAL_PARAMETER_EXT)
 	i(GL_ALPHA_MIN_SGIX)
 	i(GL_ALPHA_MAX_SGIX)
+#if defined(GL_SGIX_impact_pixel_texture)
 	i(GL_PIXEL_TEX_GEN_Q_CEILING_SGIX)
 	i(GL_PIXEL_TEX_GEN_Q_ROUND_SGIX)
 	i(GL_PIXEL_TEX_GEN_Q_FLOOR_SGIX)
@@ -2075,6 +2078,7 @@ if (!strncmp(name, "GL_", 3)) {
 	i(GL_PIXEL_TEX_GEN_ALPHA_NO_REPLACE_SGIX)
 	i(GL_PIXEL_TEX_GEN_ALPHA_LS_SGIX)
 	i(GL_PIXEL_TEX_GEN_ALPHA_MS_SGIX)
+#endif
 	i(GL_BGR_EXT)
 	i(GL_BGRA_EXT)
 	i(GL_ASYNC_MARKER_SGIX)
@@ -2161,8 +2165,10 @@ if (!strncmp(name, "GL_", 3)) {
 	i(GL_OPERAND2_ALPHA_EXT)
 	i(GL_LIGHT_MODEL_SPECULAR_VECTOR_APPLE)
 	i(GL_TRANSFORM_HINT_APPLE)
+#if defined(GL_SGIX_fog_scale)
 	i(GL_FOG_SCALE_SGIX)
 	i(GL_FOG_SCALE_VALUE_SGIX)
+#endif
 	i(GL_UNPACK_CONSTANT_DATA_SUNX)
 	i(GL_TEXTURE_CONSTANT_DATA_SUNX)
 	i(GL_GLOBAL_ALPHA_SUN)
@@ -2333,9 +2339,11 @@ if (!strncmp(name, "GL_", 3)) {
 	i(GL_PIXEL_SUBSAMPLE_4242_SGIX)
 	i(GL_YCRCB_SGIX)
 	i(GL_YCRCBA_SGIX)
+#if defined(GL_SGI_depth_pass_instrument)
 	i(GL_DEPTH_PASS_INSTRUMENT_SGIX)
 	i(GL_DEPTH_PASS_INSTRUMENT_COUNTERS_SGIX)
 	i(GL_DEPTH_PASS_INSTRUMENT_MAX_SGIX)
+#endif
 	i(GL_COMPRESSED_RGB_FXT1_3DFX)
 	i(GL_COMPRESSED_RGBA_FXT1_3DFX)
 	i(GL_MULTISAMPLE_3DFX)
@@ -3071,6 +3079,44 @@ if (!strncmp(name, "GL_", 3)) {
 	i(MAX_GL_FOG_COUNT)
 	i(MAX_GL_GET_COUNT)
 
+#ifdef GL_VERSION_1_3
+	i(GL_TEXTURE0)
+	i(GL_TEXTURE1)
+	i(GL_TEXTURE2)
+	i(GL_TEXTURE3)
+	i(GL_TEXTURE4)
+	i(GL_TEXTURE5)
+	i(GL_TEXTURE6)
+	i(GL_TEXTURE7)
+	i(GL_TEXTURE8)
+	i(GL_TEXTURE9)
+	i(GL_TEXTURE10)
+	i(GL_TEXTURE11)
+	i(GL_TEXTURE12)
+	i(GL_TEXTURE13)
+	i(GL_TEXTURE14)
+	i(GL_TEXTURE15)
+	i(GL_TEXTURE16)
+	i(GL_TEXTURE17)
+	i(GL_TEXTURE18)
+	i(GL_TEXTURE19)
+	i(GL_TEXTURE20)
+	i(GL_TEXTURE21)
+	i(GL_TEXTURE22)
+	i(GL_TEXTURE23)
+	i(GL_TEXTURE24)
+	i(GL_TEXTURE25)
+	i(GL_TEXTURE26)
+	i(GL_TEXTURE27)
+	i(GL_TEXTURE28)
+	i(GL_TEXTURE29)
+	i(GL_TEXTURE30)
+	i(GL_TEXTURE31)
+	i(GL_ACTIVE_TEXTURE)
+	i(GL_CLIENT_ACTIVE_TEXTURE)
+	i(GL_MAX_TEXTURE_UNITS)
+#endif
+
 #ifdef GL_VERSION_2_1
 	i(CURRENT_RASTER_SECONDARY_COLOR)
 	i(FLOAT_MAT2x3)
