@@ -1,11 +1,27 @@
 #include <stdio.h>
 
 #if defined(HAVE_FREEGLUT)
+
+#ifdef WIN32
 #include "../include/GL/freeglut.h"
 #else
+#include <GL/freeglut.h>
+#endif
+
+#else
+
+#ifdef __APPLE__
+/* NB: not ideal -- this assumes that we always build with AGL interface on Mac OS X
+ * Ideally, the flag HAVE_AGL_GLUT should be set appropriately by Makefile.PL when building glversion
+ * and used to check here, but this will require substantial changes to the get_extensions() there
+ */
+#include <GLUT/glut.h>
+#else
 #include <GL/glut.h>
 #endif
 
+#endif
+
 #define PROGRAM "glversion"
 
 int main(int argc, char **argv)
@@ -23,7 +39,13 @@ int main(int argc, char **argv)
   idWindow = glutCreateWindow(PROGRAM);
   glutHideWindow();
 
+#ifdef GLUT_API_VERSION
+  glutVersion = GLUT_API_VERSION;
+#elif defined(FREEGLUT)
+  glutVersion = -1;
+#else
   glutVersion = glutGet(0x01FC);
+#endif
   version =     (char*)glGetString(GL_VERSION);
   vendor =      (char*)glGetString(GL_VENDOR);
   renderer =    (char*)glGetString(GL_RENDERER);
